import java.util.Arrays;
import java.util.List;

/**
 * Holder for tiles. Holder is ordered (has positions (index)).
 *
 * @author hajo
 *
 */
// Inv: tiles != null && 0 <= actualSize < tiles.length
public class Holder {

    // Use array because holder newer change
    private final Tile[] tiles;
    private int actualSize = 0;

    public Holder(int size) {
        tiles = new Tile[size];
    }

    // Pre: tile != null
    public boolean add(Tile tile) {
        if( tile == null){
            throw new IllegalArgumentException("Tile null");
        }
        for (int i = 0; i < tiles.length; i++) {
            if (tiles[i] == null) {
                tiles[i] = tile;
                actualSize++;
                return true;
            }
        }
        return false;
    }

    // Pre : 0 <= index < tiles.size()
    public Tile remove(int index) {
        Tile t = tiles[index];   // Will throw
        tiles[index] = null;
        actualSize--;
        return t;
    }

    public int actualSize() {
       return actualSize;
    }

    public int size() {
        return tiles.length;
    }

    @Override
    public String toString() {
        return Arrays.toString(tiles);
    }
}
